@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Toni Gundogdu.
+ * Copyright (C) 2009,2010 Toni Gundogdu.
  *
  * This file is part of cclive.
  * 
@@ -24,14 +24,17 @@ enum ReturnCode {
 CCLIVE_OK           = 0,
 CCLIVE_GENGETOPT,
 CCLIVE_OPTARG,
-CCLIVE_CURLINIT,
+CCLIVE_CURLINIT, /* obsolete (0.6.0+) */
 CCLIVE_NOTHINGTODO,
 CCLIVE_SYSTEM,
 CCLIVE_NOSUPPORT,
 CCLIVE_NET,
 CCLIVE_FETCH,
 CCLIVE_PARSE,
+CCLIVE_NORETRIES,
 CCLIVE_INTERNAL,
+CCLIVE_QUVI,
+CCLIVE_QUVINOLINK,
 _CCLIVE_MAX_RETURNCODES
 };
 
