@@ -1,7 +1,5 @@
 /*
- * Copyright (C) 2009 Toni Gundogdu.
- *
- * This file is part of cclive.
+ * Copyright (C) 2009,2010 Toni Gundogdu.
  * 
  * cclive is free software: you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software
@@ -39,7 +37,6 @@ private:
     Options opts;
     std::string path;
     std::string locale;
-    bool toUnicodeFlag;
 };
 
 #define optsmgr OptionsMgr::getInstance()
